URL = "https://www.yourselfquotes.com/thought-of-the-day/"
CONN_URL = "www.google.com"
SERIES_QUOTES_URL = "https://www.tvtime.com/article/top-50-unforgettable-tv-quotes"
ANIME_QUOTES_URL = "https://bayart.org/anime-quotes/"


#!/usr/bin/env python3

from quoters.extract_data import check_connection_and_generate_quote
from quoters.enum import QuoteType

class Quote:
    """
        Class Quote to print random `quotes` and `TV shows quotes`
    """
    @staticmethod
    def print():
        """
            Function to return random quotes
        """
        result = check_connection_and_generate_quote(QuoteType.QUOTE)
        if result != False:
            return result

    @staticmethod
    def print_series_quote():
        """
            Function to return random TV shows quotes
        """
        result = check_connection_and_generate_quote(QuoteType.SERIES_QUOTE)
        if result != False:
            return result

    @staticmethod
    def print_anime_quote():
        """
            Function to return random anime quotes
        """
        result = check_connection_and_generate_quote(QuoteType.ANIME_QUOTE)
        if result != False:
            return result



from distutils.core import setup

long_desc = """quoters
``A python library that gives you beautiful quotes.``

# To install
``pip install quoters``

# Documentation
``https://github.com/suman-kr/quoters``
"""

setup(
    name='quoters',
    packages=['quoters'],
    version='0.20',
    license='MIT',
    description='Pythonic random quote generator',
    long_description=long_desc,
    long_description_content_type='text/markdown',
    author='Suman Kumar',
    author_email='skcool.123bgp@gmail.com',
    url='https://github.com/suman-kr/quoters',
    download_url='https://github.com/suman-kr/quoters/archive/0.20.tar.gz',
    keywords=['RANDOM', 'QUOTES', 'SCRAPPER'],
    install_requires=[
        'requests',
        'beautifulsoup4',
        'lxml',
        'html5lib'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
)
